# LiamHsieh toolbox
Author: Liam Y. Hsieh, PhD  
Latest update: Mar 20, 2025

This package is a collection of Python utilities created for benefiting my development of prototypes/Proof-of-concepts regarding data-driven decision science. 

<!-- Activate the virtual environment (venv) you want with the installation of this package, then run the following command to install this package for your venv:  

```bash
pip install git+https://github.com/intel-sandbox/CnA-ODS-toolbox.git

```
or from downloaded project source code then unarchive (have to change to project root folder before running following command)
```bash
pip install -e .
```

The -e option is for editable install. It doesn’t make a copy of the code into the venv folder. Instead, it makes reference to where the code has been placed. -->

